import { system, world, ItemComponentTypes, EquipmentSlot, EntityComponentTypes } from '@minecraft/server';
const counter = 0;
// setup
world.afterEvents.worldInitialize.subscribe((ev) => {
    world.getDimension("overworld").runCommandAsync("function pxlsq/mob_hats/setup");
});
system.runInterval(() => {
    world.getPlayers().forEach((player) => {
        const equipmentCompPlayer = player.getComponent(EntityComponentTypes.Equippable);
        if (equipmentCompPlayer) {
            const stack = equipmentCompPlayer.getEquipment(EquipmentSlot.Mainhand);
            if (stack) {
                if (stack.getLore().length == 0) {
                    const newStack = setCustomLore(stack);
                    equipmentCompPlayer.setEquipment(EquipmentSlot.Mainhand, newStack);
                }
            }
            const hatStack = equipmentCompPlayer.getEquipment(EquipmentSlot.Head);
            if (hatStack) {
                if (hatStack.getLore().length == 0) {
                    const newStack = setCustomLore(hatStack);
                    equipmentCompPlayer.setEquipment(EquipmentSlot.Head, newStack);
                }
            }
        }
        else {
            console.warn('No equipment component found on player');
        }
    });
}, 20);
world.afterEvents.entityHurt.subscribe((e) => {
    if (e.hurtEntity.typeId == "minecraft:player") {
        const equipmentCompPlayer = e.hurtEntity.getComponent(EntityComponentTypes.Equippable);
        const hatStack = equipmentCompPlayer.getEquipment(EquipmentSlot.Head);
        var num = Math.random();
        if (hatStack) {
            if (hatStack.typeId == "pxlsq_mob_hats:skeleton_helmet") {
                if (num < 0.2) {
                    e.hurtEntity.runCommandAsync(`execute at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/drops/skeleton\"`);
                }
                e.hurtEntity.runCommandAsync(`execute at @s run particle pxlsq_mob_hats:mh_skeleton_bone_drop ~~1.8~`);
            }
            else if (hatStack.typeId == "pxlsq_mob_hats:wither_skeleton_helmet") {
                if (num < 0.2) {
                    e.hurtEntity.runCommandAsync(`execute at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/drops/wither_skeleton\"`);
                }
                e.hurtEntity.runCommandAsync(`execute at @s run particle pxlsq_mob_hats:mh_wither_skeleton_bone_drop ~~1.8~`);
            }
            else if (hatStack.typeId == "pxlsq_mob_hats:puffer_fish_helmet") {
                if (num < 0.7) {
                    e.hurtEntity.runCommandAsync(`damage @e[family=monster,r=3.5] 2 contact entity @s`);
                }
            }
            else if (hatStack.typeId == "pxlsq_mob_hats:slime_helmet") {
                e.hurtEntity.runCommandAsync(`particle pxlsq_mob_hats:mh_slime_hit_particle ~ ~1.8 ~`);
            }
            else if (hatStack.typeId == "pxlsq_mob_hats:chicken_helmet") {
                e.hurtEntity.runCommandAsync(`particle pxlsq_mob_hats:mh_chicken_hit ~ ~ ~`);
            }
        }
    }
});
world.afterEvents.itemUse.subscribe((e) => {
    if (e.itemStack.typeId == "pxlsq_mob_hats:mob_hats_info_book") {
        e.source.runCommandAsync("execute as @s at @s rotated ~ 0 positioned ^ ^ ^2 run summon pxlsq_mob_hats:mob_hats_book ~ ~0.25 ~ facing @s");
        e.source.runCommandAsync("replaceitem entity @s slot.weapon.mainhand 0 air");
    }
});
world.afterEvents.playerSpawn.subscribe((event) => {
    if (!event.initialSpawn)
        return;
    event.player.runCommandAsync("execute as @s[tag=!pxlsq_mh_book] run loot spawn ~~~ loot \"pxlsq/mob_hats/book\"");
    event.player.runCommandAsync("tag @s add pxlsq_mh_book");
});
world.afterEvents.entityDie.subscribe((e) => {
    let dead = e.deadEntity;
    if (dead.typeId == "minecraft:ender_dragon") {
        //const dropItem = new ItemStack("pxlsq_mob_hats:ender_dragon_helmet", 1);
        //dropItem.setLore(["\n§eDragon Breath attacks"]);
        dead.dimension.runCommandAsync(`execute positioned ${dead.location.x} ${dead.location.y} ${dead.location.z} as @a[r=300] at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/ender_dragon\"`);
        //dead.dimension.spawnItem(dropItem, dead.location);
    }
    else if (dead.typeId == "minecraft:elder_guardian") {
        //const dropItem = new ItemStack("pxlsq_mob_hats:elder_guardian_helmet", 1);
        //dropItem.setLore(["\n§eSwim Speed and Guardian Lazer"]);
        //dead.dimension.spawnItem(dropItem, dead.location);
        //dead.dimension.runCommandAsync(`say ${dead.location.x} ${dead.location.y} ${dead.location.z} as @a[r=50] at @s runloot spawn ~~~ loot \"pxlsq/mob_hats/elder_guardian\"`);
        dead.dimension.runCommandAsync(`execute positioned ${dead.location.x} ${dead.location.y} ${dead.location.z} as @a[r=75] at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/elder_guardian\"`);
    }
    else if (dead.typeId == "minecraft:warden") {
        //const dropItem = new ItemStack("pxlsq_mob_hats:warden_helmet", 1);
        //dropItem.setLore(["\n§eUnlocks Warden Powers"]);
        //dead.dimension.spawnItem(dropItem, dead.location);
        dead.dimension.runCommandAsync(`execute positioned ${dead.location.x} ${dead.location.y} ${dead.location.z} as @a[r=75] at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/warden\"`);
    }
    else if (dead.typeId == "minecraft:wither") {
        //const dropItem = new ItemStack("pxlsq_mob_hats:warden_helmet", 1);
        //dropItem.setLore(["\n§eUnlocks Warden Powers"]);
        //dead.dimension.spawnItem(dropItem, dead.location);
        dead.dimension.runCommandAsync(`execute positioned ${dead.location.x} ${dead.location.y} ${dead.location.z} as @a[r=75] at @s run loot spawn ~~~ loot \"pxlsq/mob_hats/wither\"`);
    }
});
function setRandomDurability(item) {
    const durabilityComponent = item.getComponent(ItemComponentTypes.Durability);
    if (durabilityComponent !== undefined) {
        durabilityComponent.damage += Math.round(durabilityComponent.maxDurability * Math.random());
    }
    return item;
}
function setCustomLore(stack) {
    if (stack.typeId == "pxlsq_mob_hats:mob_hats_info_book") {
        stack.setLore(["\n§r§eInteract to open book", "§r", "§7Shows you how to", "§7craft all of the hats ", "§7from Mob Hats."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:cow_helmet") {
        stack.setLore(["\n§eCures negative effects."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:pig_helmet") {
        stack.setLore(["\n§eUncovers trinkets ", "§eand treats from dirt."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:chicken_helmet") {
        stack.setLore(["\n§eSlows your fall ", "§eand sometimes lays an egg."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:sheep_helmet") {
        stack.setLore(["\n§eEats grass and ", "§ekeeps you cosy."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:red_mooshroom_helmet") {
        stack.setLore(["\n§eFills empty bowls  ", "§ewith tasty soup."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:brown_mooshroom_helmet") {
        stack.setLore(["\n§eFills empty bowls  ", "§ewith tasty soup."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:villager_helmet") {
        stack.setLore(["\n§eTricks Villagers into ", "§egiving you a discount."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:squid_helmet") {
        stack.setLore(["\n§eInks enemies, ", "§emaking them weaker."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:glow_squid_helmet") {
        stack.setLore(["\n§eSee in the dark  ", "§eand inks enemies, ", "§emaking them weaker."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:puffer_fish_helmet") {
        stack.setLore(["\n§eHurts enemies that ", "§eget too close to you."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:pink_axolotl_helmet") {
        stack.setLore(["\n§eGives you regeneration  ", "§eand water breathing ", "§ewhen underwater."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:brown_axolotl_helmet") {
        stack.setLore(["\n§eGives you regeneration ", "§eand water breathing ", "§ewhen underwater."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:gold_axolotl_helmet") {
        stack.setLore(["\n§eGives you regeneration ", "§eand water breathing ", "§ewhen underwater."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:cyan_axolotl_helmet") {
        stack.setLore(["\n§eGives you regeneration ", "§eand water breathing ", "§ewhen underwater."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:blue_axolotl_helmet") {
        stack.setLore(["\n§eGives you regeneration ", "§eand water breathing ", "§ewhen underwater."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:turtle_helmet") {
        stack.setLore(["\n§eGives you resistance, ", "§ewater breathing and ", "§eblows bubbles."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:ender_dragon_helmet") {
        stack.setLore(["\n§eAttacks your enemies ", "§ewith the might of ", "§ethe Ender Dragon."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:wither_helmet") {
        stack.setLore(["\n§eAttacks your enemies ", "§ewith the Wither curse."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:warden_helmet") {
        stack.setLore(["\n§eBlinds you, but gives ", "§eyou the strength of ", "§ethe mighty Warden."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:elder_guardian_helmet") {
        stack.setLore(["\n§eAttacks your enemies ", "§ewith the power of ", "§ethe Elder Guardian."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:white_splotched_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:white_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:toast_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:salt_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:gold_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:brown_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:black_rabbit_helmet") {
        stack.setLore(["\n§eLets you jump high ", "§elike a Rabbit."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:rusty_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:pale_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:black_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:striped_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:snowy_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:ashen_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:woods_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:spotted_wolf_helmet") {
        stack.setLore(["\n§eScares off Skeletons ", "§eand barks like a dog."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:chestnut_wolf_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:black_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:gray_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:calico_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:jellie_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:persian_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:ragdoll_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:red_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:siamese_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:tabby_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:tuxedo_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:white_cat_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:ocelot_helmet") {
        stack.setLore(["\n§eScares off Creepers, ", "§egives you cat-like-vision ", "§eand meows like a kitty."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:blaze_helmet") {
        stack.setLore(["\n§eAttacks your enemies ", "§ewith the flames of the Blaze ", "§eand slows your fall."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:piglin_helmet") {
        stack.setLore(["\n§eOinks like a Piglin ", "§eand can find you ", "§egold nuggets."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:zombie_piglin_helmet") {
        stack.setLore(["\n§eMakes you immune ", "§eto the hunger effect."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:ghast_helmet") {
        stack.setLore(["\n§eAttacks your enemies ", "§ewith the blast of the Ghast."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:wither_skeleton_helmet") {
        stack.setLore(["\n§eDrops bones and ", "§ecoal when you take damage."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:magma_cube_helmet") {
        stack.setLore(["\n§eGives you the abilities of a Magma Cube ", "§eand creates fire particles."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:skeleton_helmet") {
        stack.setLore(["\n§eDrops bones and ", "§earrows when you take damage."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:zombie_helmet") {
        stack.setLore(["\n§eMakes you immune to ", "§ethe hunger effect."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:creeper_helmet") {
        stack.setLore(["\n§eExplodes nearby mobs. ", "§eFun!"]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:enderman_helmet") {
        stack.setLore(["\n§eTeleports you away from ", "§eenemies and water."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:pillager_helmet") {
        stack.setLore(["\n§eGrunts when a Villager is ", "§enearby. How rude!"]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:witch_helmet") {
        stack.setLore(["\n§eRandomly gives you a ", "§epositive potion effect."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:guardian_helmet") {
        stack.setLore(["\n§eGives you the abilities ", "§eof a Guardian."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:slime_helmet") {
        stack.setLore(["\n§eGives you the abilities ", "§eof a Slime and ", "§ecreates slime particles."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:spider_helmet") {
        stack.setLore(["\n§eWebs up nearby enemies."]);
    }
    else if (stack.typeId == "pxlsq_mob_hats:cave_spider_helmet") {
        stack.setLore(["\n§ePoisons nearby enemies."]);
    }
    return stack;
}
